@@ -1,8 +1,5 @@
 from typing import List
 
-from . import client
-from . import oas
-from . import errors
-from . import model
+from . import client, errors, model, oas
 
 __all__: List[str] = ["client", "oas", "errors", "model"]
