@@ -1,16 +1,16 @@
-import sob
 import os
 import re
+from collections import OrderedDict, deque
 from copy import copy
 from datetime import date, datetime
 from itertools import chain, starmap
-from more_itertools import unique_everseen
 from typing import (
     Any,
     Callable,
     Dict,
     Iterable,
     Iterator,
+    List,
     Match,
     Optional,
     Pattern,
@@ -19,27 +19,29 @@ from typing import (
     Tuple,
     Type,
     Union,
-    List,
 )
-from collections import OrderedDict, deque
 from urllib.request import urlopen
+
+import sob
+from more_itertools import unique_everseen
 from sob.thesaurus import get_class_meta_attribute_assignment_source
+from sob.utilities import qualified_name
 from sob.utilities.inspect import (
+    calling_function_qualified_name,
     get_source,
     properties_values,
-    calling_function_qualified_name,
 )
 from sob.utilities.string import (
-    property_name,
     class_name,
+    property_name,
     split_long_docstring_lines,
 )
-from sob.utilities import qualified_name
 from sob.utilities.types import Null
-from .errors import DuplicateClassNameError
-from .oas.references import Resolver
-from .oas.model import OpenAPI, Parameter, Properties, Schema, Reference, Items
+
 from ._utilities import get_type_format_property
+from .errors import DuplicateClassNameError
+from .oas.model import Items, OpenAPI, Parameter, Properties, Reference, Schema
+from .oas.references import Resolver
 
 _META_PROPERTIES_QAULIFIED_NAME = qualified_name(sob.meta.Properties)
 _META_PROPERTIES_QAULIFIED_NAME_LENGTH = len(_META_PROPERTIES_QAULIFIED_NAME)
@@ -161,12 +163,6 @@ def get_default_class_name_from_pointer(pointer: str, name: str = "") -> str:
     return class_name_
 
 
-# endregion
-
-
-# region Private Classes
-
-
 def _get_model_import_class_source(
     model: Type[sob.abc.Model],
 ) -> Tuple[str, str]:
@@ -281,9 +277,9 @@ class _Modeler:
             .split(".")[0]
             .strip()
         )
-        self.get_class_name_from_pointer: Callable[
-            [str, str], str
-        ] = get_class_name_from_pointer
+        self.get_class_name_from_pointer: Callable[[str, str], str] = (
+            get_class_name_from_pointer
+        )
 
     def schema_defines_object(self, schema: Union[Schema, Reference]) -> bool:
         """
@@ -416,12 +412,12 @@ class _Modeler:
             ] != relative_url_pointer:
                 class_name_ = f"{class_name_}_"
             # Update the mapping
-            self._relative_urls_pointers_class_names[
-                relative_url_pointer
-            ] = class_name_
-        self._class_names_relative_urls_pointers[
-            class_name_
-        ] = relative_url_pointer
+            self._relative_urls_pointers_class_names[relative_url_pointer] = (
+                class_name_
+            )
+        self._class_names_relative_urls_pointers[class_name_] = (
+            relative_url_pointer
+        )
         return class_name_
 
     def relative_url_pointer_class_name_exists(
@@ -529,10 +525,10 @@ class _Modeler:
                         name_ in next_schema.required
                     ):
                         meta_properties[property_name_].required = True
-                    meta_properties[
-                        property_name_
-                    ] = self.extend_property_schemas(
-                        meta_properties[property_name_], (schema,)
+                    meta_properties[property_name_] = (
+                        self.extend_property_schemas(
+                            meta_properties[property_name_], (schema,)
+                        )
                     )
                 else:
                     property_ = self.get_property(
@@ -587,13 +583,13 @@ class _Modeler:
             relative_url_pointer, name
         )
         self._class_names_meta[name] = object_meta
-        object_class: Type[
-            sob.abc.Object
-        ] = sob.model.from_meta(  # type: ignore
-            name,
-            object_meta,
-            docstring=self.get_docstring(next_schema),
-            module="__main__",
+        object_class: Type[sob.abc.Object] = (
+            sob.model.from_meta(  # type: ignore
+                name,
+                object_meta,
+                docstring=self.get_docstring(next_schema),
+                module="__main__",
+            )
         )
         return object_class
 
@@ -658,14 +654,13 @@ class _Modeler:
             property_.name = name
         if (
             (isinstance(schema, Schema) and schema.nullable)
-            or
             # Swagger/OpenAPI versions prior to 3.0 do not support `nullable`,
             # so it must be assumed that null values are acceptable for
             # all attributes. Some specs use the "x-nullable" extension
             # attribute, so we check for this as well, but in the absence
             # of a `False` value for `Schema.x_nullable`, we assume all fields
             # are nullable.
-            (
+            or (
                 (self.major_version < 3)
                 and (
                     (not isinstance(schema, Schema))
@@ -1176,12 +1171,12 @@ class _Modeler:
         - name (str|None) = None
         - relative_url_pointer (str|None)
         """
-        cls: Optional[
-            Type[sob.abc.Object]
-        ] = self.get_merged_schemas_object_class(
-            (schema,),
-            name=name,
-            relative_url_pointer=relative_url_pointer,
+        cls: Optional[Type[sob.abc.Object]] = (
+            self.get_merged_schemas_object_class(
+                (schema,),
+                name=name,
+                relative_url_pointer=relative_url_pointer,
+            )
         )
         assert cls
         return cls
@@ -1427,9 +1422,11 @@ class _Modeler:
                     key=lambda sort_line: (
                         (1, sort_line)
                         if sort_line == "import sob"
-                        else (0, sort_line)
-                        if sort_line.startswith("import")
-                        else (2, sort_line)
+                        else (
+                            (0, sort_line)
+                            if sort_line.startswith("import")
+                            else (2, sort_line)
+                        )
                     ),
                 ),
                 ("\n",),
